stravalib.unithelper.UnitConverter
==================================

.. currentmodule:: stravalib.unithelper

.. autoclass:: UnitConverter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~UnitConverter.__init__
